"""Top-level package for minidata."""
import time

__author__ = """minidata"""
__email__ = 'yuanjie@xiaomi.com'
__version__ = time.strftime("%Y.%m.%d.%H.%M.%S", time.localtime())
